# OpenDSS Writer

The OpenDSS writer exports a GDM `DistributionSystem` to OpenDSS format,
producing a set of `.dss` files that can be loaded directly by OpenDSS.

## Writer Interface

```{eval-rst}
.. automodule:: ditto.writers.opendss.write
   :members:
   :show-inheritance:
```

## Component Writers

```{eval-rst}
.. automodule:: ditto.writers.opendss.opendss_mapper
   :members:
```
